@@ -105,7 +105,7 @@ public:
 				return wxDragNone;
 			}
 
-			if (!m_pLocalTreeView->m_pState->GetServer() || m_pRemoteDataObject->GetServer() != *m_pLocalTreeView->m_pState->GetServer())
+			if (!m_pLocalTreeView->m_pState->GetServer() || !m_pRemoteDataObject->GetServer().EqualsNoPass(*m_pLocalTreeView->m_pState->GetServer()))
 			{
 				wxMessageBox(_("Drag&drop between different servers has not been implemented yet."));
 				return wxDragNone;
@@ -299,13 +299,6 @@ void CLocalTreeView::SetDir(wxString localDir)
 
 	if (subDirs == _T(""))
 	{
-		wxTreeItemIdValue value;
-		wxTreeItemId child = GetFirstChild(parent, value);
-
-		//Not needed, item stays unexpanded
-		//if (child && GetItemText(child) == _T(""))
-		//	DisplayDir(parent, localDir);
-
 		SafeSelectItem(parent);
 		return;
 	}
@@ -507,7 +500,8 @@ void CLocalTreeView::DisplayDir(wxTreeItemId parent, const wxString& dirname, co
 	int attributes;
 	bool is_dir;
 	const wxLongLong size(-1);
-	while (local_filesystem.GetNextFile(file, wasLink, is_dir, 0, 0, &attributes))
+	wxDateTime date;
+	while (local_filesystem.GetNextFile(file, wasLink, is_dir, 0, &date, &attributes))
 	{
 		wxASSERT(is_dir);
 		if (file == _T(""))
@@ -523,7 +517,7 @@ void CLocalTreeView::DisplayDir(wxTreeItemId parent, const wxString& dirname, co
 		if (file != knownSubdir)
 #endif
 		{
-			if (filter.FilenameFiltered(file, dirname, true, size, true, attributes))
+			if (filter.FilenameFiltered(file, dirname, true, size, true, attributes, date.IsValid() ? &date : 0))
 				continue;
 		}
 		else
@@ -572,7 +566,8 @@ wxString CLocalTreeView::HasSubdir(const wxString& dirname)
 	int attributes;
 	bool is_dir;
 	const wxLongLong size(-1);
-	while (local_filesystem.GetNextFile(file, wasLink, is_dir, 0, 0, &attributes))
+	wxDateTime date;
+	while (local_filesystem.GetNextFile(file, wasLink, is_dir, 0, &date, &attributes))
 	{
 		wxASSERT(is_dir);
 		if (file == _T(""))
@@ -581,7 +576,7 @@ wxString CLocalTreeView::HasSubdir(const wxString& dirname)
 			continue;
 		}
 
-		if (filter.FilenameFiltered(file, dirname, true, size, true, attributes))
+		if (filter.FilenameFiltered(file, dirname, true, size, true, attributes, date.IsValid() ? &date : 0))
 			continue;
 
 		return file;
@@ -780,7 +775,8 @@ void CLocalTreeView::Refresh()
 		bool was_link;
 		bool is_dir;
 		int attributes;
-		while (local_filesystem.GetNextFile(file, was_link, is_dir, 0, 0, &attributes))
+		wxDateTime date;
+		while (local_filesystem.GetNextFile(file, was_link, is_dir, 0, &date, &attributes))
 		{
 			if (file == _T(""))
 			{
@@ -788,7 +784,7 @@ void CLocalTreeView::Refresh()
 				continue;
 			}
 
-			if (filter.FilenameFiltered(file, dir.dir, true, size, true, attributes))
+			if (filter.FilenameFiltered(file, dir.dir, true, size, true, attributes, date.IsValid() ? &date : 0))
 				continue;
 
 			dirs.push_back(file);
@@ -1148,9 +1144,9 @@ void CLocalTreeView::OnMenuUpload(wxCommandEvent& event)
 	if (!m_contextMenuItem.IsOk())
 		return;
 
-	wxString path = GetDirFromItem(m_contextMenuItem);
+	CLocalPath path(GetDirFromItem(m_contextMenuItem));
 
-	if (!CLocalPath(path).HasParent())
+	if (!path.HasParent())
 		return;
 
 	if (!m_pState->IsRemoteConnected())
@@ -1164,8 +1160,6 @@ void CLocalTreeView::OnMenuUpload(wxCommandEvent& event)
 	if (!remotePath.ChangePath(GetItemText(m_contextMenuItem)))
 		return;
 
-	if (path.Last() == wxFileName::GetPathSeparator())
-		path.RemoveLast();
 	m_pQueueView->QueueFolder(event.GetId() == XRCID("ID_ADDTOQUEUE"), false, path, remotePath, server);
 }
 
@@ -1405,7 +1399,7 @@ void CLocalTreeView::OnChar(wxKeyEvent& event)
 	wxCommandEvent cmdEvt;
 	if (event.GetKeyCode() == WXK_F2)
 		OnMenuRename(cmdEvt);
-	else if (event.GetKeyCode() == WXK_DELETE)
+	else if (event.GetKeyCode() == WXK_DELETE || event.GetKeyCode() == WXK_NUMPAD_DELETE)
 		OnMenuDelete(cmdEvt);
 	else
 		event.Skip();
@@ -1423,15 +1417,15 @@ bool CLocalTreeView::CheckSubdirStatus(wxTreeItemId& item, const wxString& path)
 	// listing that directory is slow.
 	if (GetItemParent(item) == GetRootItem() && (path == _T("/net") || path == _T("/net/")))
 	{
-			CFilterManager filter;
+		CFilterManager filter;
 
-			const int attributes = S_IRUSR | S_IXUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH;
-			if (!filter.FilenameFiltered(_T("localhost"), path, true, size, true, attributes))
-			{
-				if (!child)
-					AppendItem(item, _T(""));
-				return true;
-			}
+		const int attributes = S_IRUSR | S_IXUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH;
+		if (!filter.FilenameFiltered(_T("localhost"), path, true, size, true, attributes, 0))
+		{
+			if (!child)
+				AppendItem(item, _T(""));
+			return true;
+		}
 	}
 #endif
 
@@ -1446,14 +1440,15 @@ bool CLocalTreeView::CheckSubdirStatus(wxTreeItemId& item, const wxString& path)
 			bool wasLink;
 			int attributes;
 			enum CLocalFileSystem::local_fileType type;
+			wxDateTime date;
 			if (path.Last() == CLocalFileSystem::path_separator)
-				type = CLocalFileSystem::GetFileInfo(path + pData->m_known_subdir, wasLink, 0, 0, &attributes);
+				type = CLocalFileSystem::GetFileInfo(path + pData->m_known_subdir, wasLink, 0, &date, &attributes);
 			else
-				type = CLocalFileSystem::GetFileInfo(path + CLocalFileSystem::path_separator + pData->m_known_subdir, wasLink, 0, 0, &attributes);
+				type = CLocalFileSystem::GetFileInfo(path + CLocalFileSystem::path_separator + pData->m_known_subdir, wasLink, 0, &date, &attributes);
 			if (type == CLocalFileSystem::dir)
 			{
 				CFilterManager filter;
-				if (!filter.FilenameFiltered(pData->m_known_subdir, path, true, size, true, attributes))
+				if (!filter.FilenameFiltered(pData->m_known_subdir, path, true, size, true, attributes, date.IsValid() ? &date : 0))
 					return true;
 			}
 		}
