@@ -102,7 +102,7 @@ public:
 			return wxDragNone;
 		}
 
-		if (m_pRemoteDataObject->GetServer() != *m_pRemoteListView->m_pState->GetServer())
+		if (!m_pRemoteDataObject->GetServer().EqualsNoPass(*m_pRemoteListView->m_pState->GetServer()))
 		{
 			wxMessageBox(_("Drag&drop between different servers has not been implemented yet."));
 			return wxDragNone;
@@ -1155,6 +1155,32 @@ public:
 };
 typedef CReverseSort<CRemoteListViewSortOwnerGroup> CRemoteListViewSortOwnerGroup_Reverse;
 
+// Filenames on VMS systems have a revision suffix, e.g.
+// foo.bar;1
+// foo.bar;2
+// foo.bar;3
+wxString StripVMSRevision(const wxString& name)
+{
+	int pos = name.Find(';', true);
+	if (pos < 1)
+		return name;
+
+	const int len = name.Len();
+	if (pos == len - 1)
+		return name;
+
+	int p = pos;
+	while (++p < len)
+	{
+		const wxChar& c = name[p];
+		if (c < '0' || c > '9')
+			return name;
+	}
+
+	return name.Left(pos);
+}
+
+
 void CRemoteListView::OnItemActivated(wxListEvent &event)
 {
 	if (!m_pState->IsRemoteIdle())
@@ -1276,7 +1302,12 @@ void CRemoteListView::OnItemActivated(wxListEvent &event)
 				return;
 			}
 
-			m_pQueue->QueueFile(queue_only, true, local_path, CQueueView::ReplaceInvalidCharacters(name), name, m_pDirectoryListing->path, *pServer, entry.size);
+			wxString localFile = CQueueView::ReplaceInvalidCharacters(name);
+			if (m_pDirectoryListing->path.GetType() == VMS && COptions::Get()->GetOptionVal(OPTION_STRIP_VMS_REVISION))
+				localFile = StripVMSRevision(localFile);
+			m_pQueue->QueueFile(queue_only, true, name,
+				(name == localFile) ? wxString() : localFile,
+				local_path, m_pDirectoryListing->path, *pServer, entry.size);
 			m_pQueue->QueueFile_Finish(true);
 		}
 	}
@@ -1540,7 +1571,12 @@ void CRemoteListView::TransferSelectedFiles(const CLocalPath& local_parent, bool
 		}
 		else
 		{
-			m_pQueue->QueueFile(queueOnly, true, local_parent, CQueueView::ReplaceInvalidCharacters(name), name, m_pDirectoryListing->path, *pServer, entry.size);
+			wxString localFile = CQueueView::ReplaceInvalidCharacters(name);
+			if (m_pDirectoryListing->path.GetType() == VMS && COptions::Get()->GetOptionVal(OPTION_STRIP_VMS_REVISION))
+				localFile = StripVMSRevision(localFile);
+			m_pQueue->QueueFile(queueOnly, true,
+				name, (name == localFile) ? wxString() : localFile,
+				local_parent, m_pDirectoryListing->path, *pServer, entry.size);
 			added = true;
 		}
 	}
@@ -2454,8 +2490,6 @@ void CRemoteListView::OnBeginDrag(wxListEvent& event)
 		return;
 	}
 
-	const wxDataFormat fmt = object.GetReceivedFormat();
-
 #if FZ3_USESHELLEXT
 	if (ext)
 	{
@@ -2691,7 +2725,8 @@ void CRemoteListView::OnMenuEdit(wxCommandEvent& event)
 		wxString localFile;
 		CLocalPath localPath(file, &localFile);
 
-		m_pQueue->QueueFile(false, true, localPath, localFile, entry.name, path, server, entry.size, CEditHandler::remote);
+		m_pQueue->QueueFile(false, true, entry.name, (localFile != entry.name) ? localFile : wxString(),
+			localPath, path, server, entry.size, CEditHandler::remote);
 		m_pQueue->QueueFile_Finish(true);
 	}
 }
@@ -2851,31 +2886,6 @@ wxListItemAttr* CRemoteListView::OnGetItemAttr(long item) const
 	return 0;
 }
 
-// Filenames on VMS systems have a revision suffix, e.g.
-// foo.bar;1
-// foo.bar;2
-// foo.bar;3
-wxString StripVMSRevision(const wxString& name)
-{
-	int pos = name.Find(';', true);
-	if (pos < 1)
-		return name;
-
-	const int len = name.Len();
-	if (pos == len - 1)
-		return name;
-
-	int p = pos;
-	while (++p < len)
-	{
-		const wxChar& c = name[p];
-		if (c < '0' || c > '9')
-			return name;
-	}
-
-	return name.Left(pos);
-}
-
 wxString CRemoteListView::GetItemText(int item, unsigned int column)
 {
 	int index = GetItemIndex(item);
@@ -2997,7 +3007,12 @@ void CRemoteListView::LinkIsNotDir(const CServerPath& path, const wxString& link
 
 	if (m_pLinkResolveState->remote_path == path && m_pLinkResolveState->link == link)
 	{
-		m_pQueue->QueueFile(false, true, m_pLinkResolveState->local_path, CQueueView::ReplaceInvalidCharacters(link), link, m_pLinkResolveState->remote_path, m_pLinkResolveState->server, -1);
+		wxString localFile = CQueueView::ReplaceInvalidCharacters(link);
+		if (m_pDirectoryListing->path.GetType() == VMS && COptions::Get()->GetOptionVal(OPTION_STRIP_VMS_REVISION))
+			localFile = StripVMSRevision(localFile);
+		m_pQueue->QueueFile(false, true,
+			link, (link != localFile) ? localFile : wxString(),
+			m_pLinkResolveState->local_path, m_pLinkResolveState->remote_path, m_pLinkResolveState->server, -1);
 		m_pQueue->QueueFile_Finish(true);
 	}
 
@@ -3015,7 +3030,7 @@ void CRemoteListView::OnMenuGeturl(wxCommandEvent& event)
 		return;
 
 	long item = -1;
-	
+
 	std::list<CDirentry> selected_item_list;
 	while ((item = GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED)) != -1)
 	{
