@@ -1,4 +1,4 @@
-#include "FileZilla.h"
+#include <filezilla.h>
 #include "loginmanager.h"
 #include "filezillaapp.h"
 
@@ -6,7 +6,7 @@ CLoginManager CLoginManager::m_theLoginManager;
 
 bool CLoginManager::GetPassword(CServer &server, bool silent, wxString name /*=_T("")*/, wxString challenge /*=_T("")*/)
 {
-	wxASSERT(!silent || server.GetLogonType() == ASK);
+	wxASSERT(!silent || server.GetLogonType() == ASK || server.GetLogonType() == INTERACTIVE);
 	wxASSERT(challenge == _T("") || server.GetLogonType() == INTERACTIVE);
 
 	if (server.GetLogonType() == ASK)
@@ -74,6 +74,8 @@ bool CLoginManager::DisplayDialog(CServer &server, wxString name, wxString chall
 		}
 		else
 			XRCCTRL(pwdDlg, "ID_HEADER_USER", wxStaticText)->Hide();
+
+		XRCCTRL(pwdDlg, "ID_NEW_USER", wxTextCtrl)->SetFocus();
 	}
 	else
 	{
